<?php

namespace Restaurant\Phone\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Restaurant\Phone\Http\Requests\PhoneRequest;
use Restaurant\Phone\Interfaces\PhoneRepositoryInterface;
use Restaurant\Phone\Models\Phone;
use Restaurant\Phone\Forms\Phone as Form;

/**
 * APIController  class for phone.
 */
class PhoneAPIController extends BaseController
{

    /**
     * Initialize phone resource controller.
     *
     * @param type PhoneRepositoryInterface $phone
     *
     * @return null
     */
    public function __construct(PhoneRepositoryInterface $phone)
    {
        parent::__construct();
        $this->repository = $phone;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Restaurant\Phone\Repositories\Criteria\PhoneResourceCriteria::class);
    }

    /**
     * Display a list of phone.
     *
     * @return Response
     */
    public function index(PhoneRequest $request)
    {
        return $this->repository
            ->setPresenter(\Restaurant\Phone\Repositories\Presenter\PhonePresenter::class)
            ->paginate();
    }

    /**
     * Display phone.
     *
     * @param Request $request
     * @param Model   $phone
     *
     * @return Response
     */
    public function show(PhoneRequest $request, Phone $phone)
    {
        return $phone->setPresenter(\Restaurant\Phone\Repositories\Presenter\PhoneListPresenter::class);
        ;
    }

    /**
     * Create new phone.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PhoneRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('phone::phone.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('phone/phone/' . $phone->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('phone/phone');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the phone.
     *
     * @param Request $request
     * @param Model   $phone
     *
     * @return Response
     */
    public function update(PhoneRequest $request, Phone $phone)
    {
        try {
            $data = $request->all();

            $phone->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('phone::phone.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('phone/phone/' . $phone->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('phone/phone/' . $phone->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the phone.
     *
     * @param Model   $phone
     *
     * @return Response
     */
    public function destroy(PhoneRequest $request, Phone $phone)
    {
        try {
            $phone->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('phone::phone.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('phone/phone/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('phone/phone/' . $phone->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
