<?php

namespace Restaurant\Phone\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Restaurant\Phone\Interfaces\PhoneRepositoryInterface;

class PhonePublicController extends BaseController
{
    // use PhoneWorkflow;

    /**
     * Constructor.
     *
     * @param type \Restaurant\Phone\Interfaces\PhoneRepositoryInterface $phone
     *
     * @return type
     */
    public function __construct(PhoneRepositoryInterface $phone)
    {
        $this->repository = $phone;
        parent::__construct();
    }

    /**
     * Show phone's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $phones = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('phone::phone.names'))
            ->view('phone::public.phone.index')
            ->data(compact('phones'))
            ->output();
    }


    /**
     * Show phone.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $phone = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($phone->name . trans('phone::phone.name'))
            ->view('phone::public.phone.show')
            ->data(compact('phone'))
            ->output();
    }

}
