<?php

namespace Restaurant\Phone\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Phone\Models\Phone;

class PhonePolicy
{

    /**
     * Determine if the given user can view the phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function view(UserPolicy $user, Phone $phone)
    {
        if ($user->canDo('phone.phone.view') && $user->isAdmin()) {
            return true;
        }

        return $phone->user_id == user_id() && $phone->user_type == user_type();
    }

    /**
     * Determine if the given user can create a phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('phone.phone.create');
    }

    /**
     * Determine if the given user can update the given phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function update(UserPolicy $user, Phone $phone)
    {
        if ($user->canDo('phone.phone.edit') && $user->isAdmin()) {
            return true;
        }

        return $phone->user_id == user_id() && $phone->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Phone $phone)
    {
        return $phone->user_id == user_id() && $phone->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Phone $phone)
    {
        if ($user->canDo('phone.phone.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given phone.
     *
     * @param UserPolicy $user
     * @param Phone $phone
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Phone $phone)
    {
        if ($user->canDo('phone.phone.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
